PAWpySeed: /home/kyle/Research/projects/pawpyseed/pawpyseed/core/pseudoprojector.h File Reference

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- File List
- File Members

Functions
pseudoprojector.h File Reference
`#include "utils.h"`
Include dependency graph for pseudoprojector.h:

Go to the source code of this file.

## Functions
void | vc_pseudoprojection (pswf_t *wf_ref, pswf_t *wf_proj, int BAND_NUM, double *results)
double * | pseudoprojection (pswf_t *wf_ref, pswf_t *wf_proj, int BAND_NUM)

## Detailed Description

Routines for calculating the overlaps of pseudowavefunctions (i.e. sums of plane-wave coefficients).

## Function Documentation

double* pseudoprojection | ( | pswf_t * | wf_ref,
|  | pswf_t * | wf_proj,
|  | int | BAND_NUM
| ) |  |

Takes two pswf_t objects and a band number BAND_NUM. For each kpoint and spin, the band BAND_NUM of wf_proj will be projected onto all bands of wf_ref at that kpoint and spin, i.e. th overlap operators are calculated and returned as a double* res, where if I is the imaginary unit and j is an index, res[2*j] + I*res[2*j+1] is the value of an overlap operator.

The format of the returned array is as follows: loop over bands loops over spins loop over kpoints

void vc_pseudoprojection | ( | pswf_t * | wf_ref,
|  | pswf_t * | wf_proj,
|  | int | BAND_NUM,
|  | double * | results
| ) |  |

DEPRECATED, DO NOT USE